from distutils.core import setup

setup(
    name='mydates1',
    version='0.0.1',
    author='jiangqingliu',
    author_email='jiangqingliu822@gmail.com',
    # url='www.baidu.com',
    license='LICENSE',
    packages=['mydates1'],
    description='An example of building Python package.',
    install_requires=[
        # 'python>=3.6.0',
        # 'pandas>=0.10.0'
    ]
)
